@@ -5,6 +5,7 @@ from os import sys
 from optparse import OptionParser
 from mingus.core import notes
 import Bands
+import Progressions
 
 try:
 	from mingus.extra import fluidsynth
@@ -17,6 +18,11 @@ def get_available_bands():
 	return [x for x in Bands.__dict__ if \
 		type(getattr(Bands, x)) == type([])]
 
+def get_available_progressions():
+	return [x for x in Progressions.__dict__ if \
+		type(getattr(Progressions, x)) == type([]) and \
+		x[0] != "_"]
+
 if __name__ == '__main__':
 
 	parser = OptionParser()
@@ -28,19 +34,26 @@ if __name__ == '__main__':
 		metavar="EN", help="Set the ensemble")
 	parser.add_option("-f", "--frontend", dest="frontend", 
 		metavar="F", help="Choose front-end [blocks, lines, mixed]")
-	parser.add_option("-l", "--list", action="store_true", 
-		dest="list_bands", default=False, 
-		help="List available ensembles. Don't play.")
+	parser.add_option("--height", dest='height', type='int',
+		default=400, help='Height of the visualization screen')
+	parser.add_option("-l", "--list", dest="list", 
+		help="List [bands, progressions]. Don't play.")
 	parser.add_option("-k", "--key", dest="key",
 		help="Set the key to start in.")
+	parser.add_option("-p", "--progression", dest="progression",
+		help="Set the progression.")
+	parser.add_option("-r", "--resolution", dest="resolution",
+		default=8, type="int",
+		help="The resolution [1,2,4,8,16,32,etc]")
 	parser.add_option("-q", "--quiet", action="store_false",
-		dest="verbose")
+		dest="verbose", default=True, 
+		help="Don't output to stdout")
 	parser.add_option("-s", "--swing", action="store_true",
 		dest="swing", default=False, help="Set swing")
-	parser.add_option("-v", "--verbose", action="store_true", 
-		dest="verbose", default=True)
 	parser.add_option("-w", "--wildness", type="float", dest="wild",
 		help="Floating point number indicating wildness")
+	parser.add_option("--width", dest="width", default=400,
+		type="int", help="Width of the visualization screen")
 
 	(options, args) = parser.parse_args()
 
@@ -48,32 +61,52 @@ if __name__ == '__main__':
 	visual = None
 	block = Block()
 	block.swing = options.swing
+	block.resolution = options.resolution
+	w = options.width
+	h = options.height
 
 	if options.frontend == "blocks":
 		from Visualizations import PygameBlockVisualization
-		visual = PygameBlockVisualization(400,400)
+		visual = PygameBlockVisualization(w,h)
 	elif options.frontend == "lines":
 		from Visualizations import PygameLineVisualization
-		visual = PygameLineVisualization(400,400)
+		visual = PygameLineVisualization(w,h)
 	elif options.frontend == "mixed":
 		from Visualizations import PygameMixedVisualizations
-		visual = PygameMixedVisualizations(400,400)
+		visual = PygameMixedVisualizations(w,h)
 
-	if options.list_bands:
-		i = 1
-		for x in get_available_bands():
-			print "%d. %s" % (i, x)
-			i += 1
+	if options.list != None:
+		if options.list == "bands" or \
+			options.list[0] == 'b':
+			i = 1
+			for x in get_available_bands():
+				print "%d. %s" % (i, x)
+				i += 1
+		elif options.list == "progressions" or\
+			options.list[0] == 'p':
+			i = 1
+			for x in get_available_progressions():
+				print "%d. %s" % (i, x)
+				i += 1
+		else:
+			print "Unknown list", options.list
 		sys.exit(0)
 
 	if options.ensemble != None:
 		if options.ensemble in get_available_bands():
-			block.instruments = getattr(Bands, options.ensemble)
+			block.instruments = getattr(Bands, 
+					options.ensemble)
 		else:
 			if options.verbose:
 				print "Unknown ensemble:", options.ensemble
 
-
+	if options.progression != None:
+		if options.progression in get_available_progressions():
+			block.progressions = getattr(Progressions, 
+					options.progression)
+		else:
+			if options.verbose:
+				print "Unknown progression:", options.progression
 
 	if options.key != None:
 		if notes.is_valid_note(options.key):
