@@ -29,11 +29,11 @@ class Instrument:
 		if 'step' in parameters:
 			self.step = parameters["step"]
 
-		if 'midi-instr' in parameters:
-			fluidsynth.midi.set_instrument(self.params["channel"], self.params["midi-instr"])
-
-
 	def play(self, state):
+
+		if 'midi_instr' in self.params:
+			fluidsynth.midi.set_instrument(self.params["channel"], self.params["midi_instr"])
+
 			
 		if 'let_ring' not in self.params:
 			self.stop_playing_notes()
