@@ -1,10 +1,15 @@
 from Instrument import Instrument
 from mingus.containers.Note import Note
 from mingus.core import notes
-from random import choice, random
+from random import choice, random, randrange
 
 class BassInstrument(Instrument):
 
+	def __init__(self, params):
+		if 'midi_instr' not in params:
+			params["midi_instr"] = randrange(33,37)
+		Instrument.__init__(self, params)
+
 	def generate_note(self, state):
 		wild = 1.0
 		if 'wild' in state:
@@ -13,7 +18,11 @@ class BassInstrument(Instrument):
 		if state["tick"] % (state["resolution"] / 4.0) == 0 and \
 				random() < 1.0 * wild:
 			n = Note(choice(state["chord"]))
-			n.octave_down()
+			while n > Note("E", 3):
+				if n.octave >= 3:
+					n.octave_down()
+				else:
+					break
 			return [n]
 		elif state["tick"] % (state["resolution"] / 4.0) == \
 				state["resolution"] / 8 and \
@@ -21,5 +30,6 @@ class BassInstrument(Instrument):
 			
 			n = Note(choice(state["chord"]))
 			n.octave_down()
+			n.octave_down()
 			n.name = notes.diminish(n.name)
 			return [n]
